#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/install.sh - installation file for mailx services on EIS/FAIR
#
# Copyright (c) 2018-2018  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2018-02-03  jed
# Last Update:  $Id: $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

module_name='mailx'

# debug mode: true/false
#debug=true
if ${debug:-false}
then
    exec 2>/tmp/${module_name}-$(basename ${0})-trace$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

myecho --pack ${module_name} --info "running install.sh ..."

# update shared library file
update_jedlib ${module_name}

# mailx v1.0.0
for PNAME in mail ssmtp
do
    filelist=/etc/filelist.d/${PNAME}-files.txt
    deinstallfile=/var/install/deinstall/${PNAME}

    if [ -f ${filelist} ]
    then
        # remove mailx program from file list
        grep -q "${PNAME} usr/bin/mail$" ${filelist}

        if [ $? -eq 0 ]
        then
            myecho --pack ${module_name} --info "removing mailx references from '${PNAME}' file list ..."
            cp ${filelist} ${filelist}.tmp
            grep -v "${PNAME} usr/bin/mail$" ${filelist}.tmp > ${filelist}
            rm -f ${filelist}.tmp
        fi
    fi

    if [ -f ${deinstallfile} ]
    then
        # remove mailx entries from deinstall script
        grep -E -q "/bin/mail$|/bin/mailx|mailx" ${deinstallfile}

        if [ $? -eq 0 ]
        then
            myecho --pack ${module_name} --info "removing mailx references from '${PNAME}' deinstall script ..."
            cp ${deinstallfile} ${deinstallfile}.tmp
            grep -E -v "/bin/mail$|/bin/mailx$" ${deinstallfile}.tmp | sed 's/mailx //' > ${deinstallfile}
            rm -f ${deinstallfile}.tmp
        fi
    fi
done

exit 0
